# Requires factories and other useful helpers defined in harpiya_core.
require 'harpiya/testing_support/authorization_helpers'
require 'harpiya/testing_support/capybara_ext'
require 'harpiya/testing_support/factories'
require 'harpiya/testing_support/preferences'
require 'harpiya/testing_support/controller_requests'
require 'harpiya/testing_support/flash'
require 'harpiya/testing_support/url_helpers'
require 'harpiya/testing_support/order_walkthrough'
require 'harpiya/testing_support/auth_helpers'
require 'harpiya/testing_support/checkout_helpers'
require 'harpiya/testing_support/caching'

# API helpers
if defined?(Harpiya::Api)
  require 'harpiya/api/testing_support/helpers'
  require 'harpiya/api/testing_support/setup'
end

# API v2 helpers
if defined?(Harpiya::Api) && Harpiya.version.to_f >= 3.7
  require 'jsonapi/rspec'
  require 'harpiya/api/testing_support/v2/base'
  require 'harpiya/api/testing_support/v2/current_order'
end

RSpec.configure do |config|
  # Infer an example group's spec type from the file location.
  config.infer_spec_type_from_file_location!

  # == URL Helpers
  #
  # Allows access to Harpiya's routes in specs:
  #
  # visit harpiya.admin_path
  # current_path.should eql(harpiya.products_path)
  config.include Harpiya::TestingSupport::UrlHelpers

  # == Requests support
  #
  # Adds convenient methods to request Harpiya's controllers
  # harpiya_get :index
  config.include Harpiya::TestingSupport::ControllerRequests, type: :controller

  config.include Harpiya::TestingSupport::Preferences
  config.include Harpiya::TestingSupport::Flash

  config.include Harpiya::TestingSupport::AuthHelpers, type: :feature
  config.include Harpiya::TestingSupport::CheckoutHelpers, type: :feature

  if defined?(Harpiya::Api)
    config.include Harpiya::Api::TestingSupport::Helpers # needed for API v1
    config.extend Harpiya::Api::TestingSupport::Setup, type: :request
  end
  if Harpiya.version.to_f >= 3.7
    config.include JSONAPI::RSpec, type: :request # required for API v2 request specs
  end

  config.before :each do
    Rails.cache.clear
    reset_harpiya_preferences do |config|
      # config.my_custom_preference = 10
    end
    create(:store)
  end
end
